/*  File: mod-jets.cc
 *  Project: Deductor
 *  Created by Zoltán Nagy on 9/8/13.
 *  Modified by D. Soper on 11 January 2019.
 *
 *  This program is free software: you can redistribute it and/or modify
 *  it under the terms of the GNU General Public License as published by
 *  the Free Software Foundation, either version 3 of the License, or
 *  (at your option) any later version.
 *
 *  This program is distributed in the hope that it will be useful,
 *  but WITHOUT ANY WARRANTY; without even the implied warranty of
 *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
 *  GNU General Public License for more details.
 *
 *  You should have received a copy of the GNU General Public License
 *  along with this program. If not, see <http://www.gnu.org/licenses/>.
 */

/*   Deductor headers  */
#include <deductor.h>
#include <proc-hhcjets.h>

/*   Analyser headers  */
#include "analyzer-jets.h"



auto my_jet_module(const deductor_input&)
{
  /*  Using a previously creating the kernel   */
  deductor<hhc> kernel{qcd::ct14n};
  
  /*    Hard process     */
  auto hard = [=](const model_ref& mdl) -> hhcjets
  {
    int proton = 2212;
    double Ecm = 13.0_TeV;
    double scalefac_pert = 0.707;
    double scalefac_shw = 1.5;
    
    auto pTlist = {
      100.0, 300.0, 400.0, 600.0, 800.0, 1200.0, 1600.0,
      2000.0, 2500.0, 3000.0, 3500.0, 4000.0, 4500.0, 5000.0
    };
    
    return {mdl, Ecm, pTlist, scalefac_pert, scalefac_shw, proton, proton};
  };
  
  /*   Jet cross section pT distribution */
  shower_engine_opts opts;
  
  opts.kT_cutoff = 5.0_GeV;      // Shower stops here.
  opts.threshold.enabled = true; // Include threshold factor.
  opts.threshold.order_of_soft_corrections = 1u;
  
  /*  Color approximation on the [tmH, tmH + tnext] evolution range for t.
   *  Here tmH is the shower time for the hard interaction.
   *  Note that later shower steps can't have better approximations than earlier steps.
   */
  opts.color[5.0] = {
    {UINT_MAX, 4u, {2u,2u,2u}},
  };
  
  opts.color[1000.0] = {
    {UINT_MAX, 4u, {0u,0u,0u}},
  };
  
  /*    starting the calculation with various user functions    */
  kernel(ordering::lambda{}, {"JetCalculations", opts}, hard,
         new UserJets{"Jets-anti-kT-R=0.2", {fj::antikt_algorithm, 0.2}},
         new UserJets{"Jets-anti-kT-R=0.4", {fj::antikt_algorithm, 0.4}},
         new UserJets{"Jets-anti-kT-R=0.7", {fj::antikt_algorithm, 0.7}});
}

/*   Always export your module functions!   */
export_my_module jets_module = {
  {"Jets-at-LHC13TeV", my_jet_module}
};

