/*  File: analyzer-unitary.h
 *  Project: Deductor
 *  Created by Zoltán Nagy on 9/8/13.
 *  Modified by D. Soper on 18 January 2019
 *
 *  This program is free software: you can redistribute it and/or modify
 *  it under the terms of the GNU General Public License as published by
 *  the Free Software Foundation, either version 3 of the License, or
 *  (at your option) any later version.
 *
 *  This program is distributed in the hope that it will be useful,
 *  but WITHOUT ANY WARRANTY; without even the implied warranty of
 *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
 *  GNU General Public License for more details.
 *
 *  You should have received a copy of the GNU General Public License
 *  along with this program. If not, see <http://www.gnu.org/licenses/>.
 */
#ifndef __analyzer_unitary_h__
#define __analyzer_unitary_h__


/*   project headers  */
#include <user.h>

/*   other includes   */



/*   It is not a library just a module. We can use using namespace...  */
using namespace std;
using namespace duct;
using namespace duct::distpoint;


/*   Narrowing the distbook template   */
using DistArr6 = distbook<std::array<double, 6>, hist1d>;
using DistArr22 = distbook<std::array<double, 22>, hist1d>;




/*   
 *   This is the declaration of the analyser class.
 */
class UserUnitary : public basic_user<hhc, DistArr6, DistArr22>
{
  /*   useful aliases  */
  using HistArr6 = Phys<DistArr6>;
  using HistArr22 = Phys<DistArr22>;
  

public:
  /*    constructors     */
  explicit UserUnitary(const char *n, const duration_type& d = 2.0min)
  { this->param(n, d, 10000000);} // weighted results in 10M chunks
  
  /*   User defined init function. It is called once at the begining of the calculation.  */
  void initfunc();
  
  /*   The analyser routine. It analyses the events and fill the histograms.   */
  void userfunc(const shower_stage<hhc>&, const shower_stage<hhc>&, const shower_stage<hhc>&);
};

#endif
